---
tags: ['version', 'release']
---

# v0.2.0 of Mophidian

Welcome to Mophidian beta version 2. Feel free to look around and break things :slightly_smiling_face:.
If you happen to find any bugs please create github issues for the appropriate repository. See
[Reporting Issues](/blog/reporting_issues/) to see how to find out where the issue belongs.

Examples are coming soon, but if you are itching for an example sooner check out this websites source code.
Yep! This website is made with mophidian.

**This version is fully functional with the following features:**

- Components
- Layouts
- Pages
- Public assets
- Live reloading
- CLI Commands
- Slots and named slots
- And much more...

While these features are basic and the minimum for a viable product, much more is planned to come!

**Upcoming features:**

- Example sites made with mophidian
- Dynamic routing
- Importing from a python file into a phml file
  - This means a designated location for python files/scripts
- Built in searchability
- Better rss and sitemap support

<Callout type="warning">
  This project is in early beta stages and is subject to change. Any and all features may change at any time.
  This library will not support backwards compatibility as of it's currant state.
</Callout>
